"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os = require("os");
const fs = require("fs");
const chalk_1 = require("chalk");
const FsHelper_1 = require("../FsHelper");
const issue_1 = require("../issue");
const InternalFormatter_1 = require("./InternalFormatter");
const codeFrame = require('babel-code-frame');
function createCodeframeFormatter(options) {
    return function codeframeFormatter(issue) {
        const color = {
            message: issue.severity === issue_1.IssueSeverity.WARNING
                ? chalk_1.default.bold.yellow
                : chalk_1.default.bold.red,
            position: chalk_1.default.dim
        };
        if (issue.origin === issue_1.IssueOrigin.INTERNAL) {
            return InternalFormatter_1.createInternalFormatter()(issue);
        }
        const file = issue.file;
        const source = file && FsHelper_1.fileExistsSync(file) && fs.readFileSync(file, 'utf-8');
        let frame = '';
        if (source) {
            frame = codeFrame(source, issue.line, // Assertion: `codeFrame` allows passing undefined, typings are incorrect
            issue.character, Object.assign({ highlightCode: true }, (options || {})))
                .split('\n')
                .map((line) => '  ' + line)
                .join(os.EOL);
        }
        const lines = [
            color.message(`${issue.severity.toUpperCase()} in ${issue.file}(${issue.line},${issue.character}):`),
            color.position(`${issue.line}:${issue.character} ${issue.message}`)
        ];
        if (frame) {
            lines.push(frame);
        }
        return lines.join(os.EOL);
    };
}
exports.createCodeframeFormatter = createCodeframeFormatter;
//# sourceMappingURL=CodeframeFormatter.js.map