"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os = require("os");
const chalk_1 = require("chalk");
const issue_1 = require("../issue");
const InternalFormatter_1 = require("./InternalFormatter");
function createDefaultFormatter() {
    return function defaultFormatter(issue) {
        const color = {
            message: issue.severity === issue_1.IssueSeverity.WARNING
                ? chalk_1.default.bold.yellow
                : chalk_1.default.bold.red,
            position: chalk_1.default.bold.cyan,
            code: chalk_1.default.grey
        };
        if (issue.origin === issue_1.IssueOrigin.INTERNAL) {
            return InternalFormatter_1.createInternalFormatter()(issue);
        }
        const code = issue.origin === issue_1.IssueOrigin.TYPESCRIPT ? `TS${issue.code}` : issue.code;
        return [
            color.message(`${issue.severity.toUpperCase()} in `) +
                color.position(`${issue.file}(${issue.line},${issue.character})`) +
                color.message(':'),
            color.code(code + ': ') + issue.message
        ].join(os.EOL);
    };
}
exports.createDefaultFormatter = createDefaultFormatter;
//# sourceMappingURL=DefaultFormatter.js.map