"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Issue_1 = require("../Issue");
const IssueOrigin_1 = require("../IssueOrigin");
const IssueSeverity_1 = require("../IssueSeverity");
function createIssueFromEsLintMessage(message) {
    return {
        origin: IssueOrigin_1.IssueOrigin.ESLINT,
        code: message.ruleId ? String(message.ruleId) : '[unknown]',
        severity: message.severity === 1 ? IssueSeverity_1.IssueSeverity.WARNING : IssueSeverity_1.IssueSeverity.ERROR,
        message: message.message,
        file: message.filePath,
        line: message.line,
        character: message.column
    };
}
function createFileAwareEsLintMessagesFromEsLintResult(result) {
    return result.messages.map(message => (Object.assign({}, message, { filePath: result.filePath })));
}
function createFileAwareEsLintMessagesFromEsLintReport(report) {
    return report.results.reduce((messages, result) => [
        ...messages,
        ...createFileAwareEsLintMessagesFromEsLintResult(result)
    ], []);
}
function createFileAwareEsLintMessagesFromEsLintReports(reports) {
    return reports.reduce((messages, report) => [
        ...messages,
        ...createFileAwareEsLintMessagesFromEsLintReport(report)
    ], []);
}
function createIssuesFromEsLintMessages(messages) {
    return Issue_1.deduplicateAndSortIssues(messages.map(createIssueFromEsLintMessage));
}
function createIssuesFromEsLintReports(reports) {
    return createIssuesFromEsLintMessages(createFileAwareEsLintMessagesFromEsLintReports(reports));
}
exports.createIssuesFromEsLintReports = createIssuesFromEsLintReports;
//# sourceMappingURL=EsLintIssueFactory.js.map